# --------------------------------------------------------------------------- #


import base64

# --------------------------------------------------------------------------- #


def get_package_version() -> str:
    from .__version__ import __version__
    return __version__


def file_to_bytes(path: str) -> bytes:
    """
    Load data from a file as bytes.

    :param path: The path for the file to load.

    :returns: The loaded file bytes.
    :raises FileNotFoundError: If the file given via ``path`` could not be
     found.
    """
    with open(path, mode='rb') as f:
        data = f.read()
    return data


def bytes_to_file(path: str, data: bytes) -> None:
    """
    Writes bytes to the given file.

    :param path: The path for the file to write.
    :param data: The file bytes.

    :raises PermissionError: If there is a lack of permission to write to
     the given ``path`` location.
    """
    with open(path, mode='wb') as f:
        f.write(data)


def jose_b64encode(s):
    """
    Base64 encodes the given data via:
        - URL safe encoding
        - Stripped padding

    :param s: Data to encode.
    :return: Base64 encoded data as a string.
    """
    if isinstance(s, str):
        s = s.encode()
    return base64.urlsafe_b64encode(s).rstrip(b'=').decode()


def jose_b64decode(s):
    """
    Base64 decodes the given data assuming data is:
        - URL safe encoded
        - May have padding stripped

    :param s: Data to decode from Base64.
    :return: Decoded data.
    """
    if isinstance(s, str):
        s = s.encode()
    return base64.urlsafe_b64decode(s + b'=' * (4 - (len(s) % 4)))
